@@ -16,7 +16,8 @@
 
 namespace eckit {
 
-StdFile::StdFile(const PathName& name, const std::string& mode) : file_(0) {
+StdFile::StdFile(const PathName& name, const std::string& mode) :
+    file_(0) {
     file_ = ::fopen(name.localPath(), mode.c_str());
 
     if (file_ == 0)
