@@ -16,17 +16,16 @@
 #ifndef eckit_la_SparseMatrix_h
 #define eckit_la_SparseMatrix_h
 
-#include <iosfwd>
 #include <cassert>
 #include <iosfwd>
 #include <memory>
 #include <vector>
 
-#include "eckit/linalg/types.h"
-#include "eckit/linalg/Triplet.h"
-#include "eckit/memory/NonCopyable.h"
-#include "eckit/memory/MemoryBuffer.h"
 #include "eckit/io/MemoryHandle.h"
+#include "eckit/linalg/Triplet.h"
+#include "eckit/linalg/types.h"
+#include "eckit/memory/MemoryBuffer.h"
+#include "eckit/memory/NonCopyable.h"
 
 namespace eckit {
 
@@ -41,21 +40,20 @@ namespace linalg {
 ///
 class SparseMatrix {
 
-public: // types
-
+public:  // types
     struct Layout {
 
         Layout() : data_(nullptr), outer_(nullptr), inner_(nullptr) {}
 
         void reset() {
-            data_   = nullptr;
-            outer_  = nullptr;
-            inner_  = nullptr;
+            data_  = nullptr;
+            outer_ = nullptr;
+            inner_ = nullptr;
         }
 
-        Scalar*      data_;   ///< matrix entries, sized with number of non-zeros (nnz)
-        Index*       outer_;  ///< start of rows,  sized number of rows + 1
-        Index*       inner_;  ///< column indices, sized with number of non-zeros (nnz)
+        Scalar* data_;  ///< matrix entries, sized with number of non-zeros (nnz)
+        Index* outer_;  ///< start of rows,  sized number of rows + 1
+        Index* inner_;  ///< column indices, sized with number of non-zeros (nnz)
     };
 
     struct Shape {
@@ -63,9 +61,9 @@ public: // types
         Shape() : size_(0), rows_(0), cols_(0) {}
 
         void reset() {
-            size_  = 0;
-            rows_  = 0;
-            cols_  = 0;
+            size_ = 0;
+            rows_ = 0;
+            cols_ = 0;
         }
 
         /// @returns number of rows
@@ -88,28 +86,30 @@ public: // types
 
         size_t allocSize() const { return sizeofData() + sizeofOuter() + sizeofInner(); }
 
-        size_t sizeofData()  const { return dataSize()  * sizeof(Scalar); }
-        size_t sizeofOuter() const { return outerSize() * sizeof(Index);  }
-        size_t sizeofInner() const { return innerSize() * sizeof(Index);  }
+        size_t sizeofData() const { return dataSize() * sizeof(Scalar); }
+        size_t sizeofOuter() const { return outerSize() * sizeof(Index); }
+        size_t sizeofInner() const { return innerSize() * sizeof(Index); }
 
-        Size         size_;   ///< Size of the container (AKA number of non-zeros nnz)
-        Size         rows_;   ///< Number of rows
-        Size         cols_;   ///< Number of columns
+        Size size_;  ///< Size of the container (AKA number of non-zeros nnz)
+        Size rows_;  ///< Number of rows
+        Size cols_;  ///< Number of columns
 
         void print(std::ostream& os) const {
             os << "Shape["
-               << "nnz="  << size_ << ","
+               << "nnz=" << size_ << ","
                << "rows=" << rows_ << ","
                << "cols=" << cols_ << "]";
         }
 
-        friend std::ostream& operator<<(std::ostream& os, const Shape& p) { p.print(os); return os; }
+        friend std::ostream& operator<<(std::ostream& os, const Shape& p) {
+            p.print(os);
+            return os;
+        }
     };
 
 
     class Allocator {
     public:
-
         virtual ~Allocator();
 
         /// @note that shape may be modified by the allocator, e.g. loading of pre-computed matrices
@@ -123,12 +123,13 @@ public: // types
 
         virtual void print(std::ostream&) const = 0;
 
-        friend std::ostream& operator<<(std::ostream& os, const Allocator& a) { a.print(os); return os; }
-
+        friend std::ostream& operator<<(std::ostream& os, const Allocator& a) {
+            a.print(os);
+            return os;
+        }
     };
 
 public:  // methods
-
     // -- Constructors
 
     /// Default constructor, empty matrix
@@ -146,16 +147,18 @@ public:  // methods
     /// Constructor from MemoryBuffer
     SparseMatrix(const MemoryBuffer&);
 
-    ~SparseMatrix();
+    /// Move constructor
+    SparseMatrix(SparseMatrix&&);
 
     /// Copy constructor
     SparseMatrix(const SparseMatrix&);
 
+    ~SparseMatrix();
+
     /// Assignment operator (allocates and copies data)
     SparseMatrix& operator=(const SparseMatrix&);
 
 public:
-
     /// Prune entries with exactly the given value
     SparseMatrix& prune(Scalar val = Scalar(0));
 
@@ -176,7 +179,7 @@ public:
     void dump(eckit::MemoryBuffer& buffer) const;
     void dump(void* buffer, size_t size) const;
 
-    static void load(const void* buffer, size_t bufferSize, Layout& layout, Shape& shape); ///< from dump()
+    static void load(const void* buffer, size_t bufferSize, Layout& layout, Shape& shape);  ///< from dump()
 
     void swap(SparseMatrix& other);
 
@@ -201,6 +204,9 @@ public:
     /// @returns read-only view of the inner index vector
     const Index* inner() const { return spm_.inner_; }
 
+    /// Set a new number of columns (may invalidate data)
+    void cols(Size cols);
+
     /// Reserve memory for given number of non-zeros (invalidates all data arrays)
     /// @note variables into this method must be by value
     void reserve(Size rows, Size cols, Size nnz);
@@ -217,26 +223,26 @@ public:
 
     const Allocator& owner() const;
 
-    friend std::ostream& operator<<(std::ostream& os, const SparseMatrix& m) { m.print(os); return os; }
-
-public: // iterators
+    friend std::ostream& operator<<(std::ostream& os, const SparseMatrix& m) {
+        m.print(os);
+        return os;
+    }
 
+public:  // iterators
     struct const_iterator {
 
         const_iterator(const SparseMatrix& matrix);
         const_iterator(const SparseMatrix& matrix, Size row);
 
-        const_iterator(const const_iterator& other) {
-            *this = other;
-        }
+        const_iterator(const const_iterator& other) { *this = other; }
 
         Size col() const;
         Size row() const;
 
-        operator bool() const { return matrix_ && ( index_ < matrix_->nonZeros() ); }
+        operator bool() const { return matrix_ && (index_ < matrix_->nonZeros()); }
 
         const_iterator& operator++();
-        const_iterator  operator++(int);
+        const_iterator operator++(int);
         const_iterator& operator=(const const_iterator& other);
 
         bool operator!=(const const_iterator& other) const { return !operator==(other); }
@@ -249,11 +255,9 @@ public: // iterators
         bool lastOfRow() const { return ((index_ + 1) == Size(matrix_->outer()[row_ + 1])); }
 
     protected:
-
         SparseMatrix* matrix_;
         Size index_;
         Size row_;
-
     };
 
     struct iterator : const_iterator {
@@ -262,24 +266,23 @@ public: // iterators
         Scalar& operator*();
     };
 
-    /// const iterators to being/end of row
-    const_iterator begin(Size row)   const { return const_iterator(*this, row); }
-    const_iterator end(Size row)     const { return const_iterator(*this, row+1); }
+    /// const iterators to begin/end of row
+    const_iterator begin(Size row) const { return const_iterator(*this, row); }
+    const_iterator end(Size row) const { return const_iterator(*this, row + 1); }
 
-    /// const iterators to being/end of matrix
-    const_iterator begin()           const { return const_iterator(*this); }
-    const_iterator end()             const { return const_iterator(*this, rows()); }
+    /// const iterators to begin/end of matrix
+    const_iterator begin() const { return const_iterator(*this); }
+    const_iterator end() const { return const_iterator(*this, rows()); }
 
-    /// iterators to being/end of row
-    iterator       begin(Size row)   { return iterator(*this, row); }
-    iterator       end(Size row)     { return iterator(*this, row+1); }
+    /// iterators to begin/end of row
+    iterator begin(Size row) { return iterator(*this, row); }
+    iterator end(Size row) { return iterator(*this, row + 1); }
 
-    /// const iterators to being/end of matrix
-    iterator       begin()           { return iterator(*this); }
-    iterator       end()             { return iterator(*this, rows()); }
-
-private: // methods
+    /// const iterators to begin/end of matrix
+    iterator begin() { return iterator(*this); }
+    iterator end() { return iterator(*this, rows()); }
 
+private:  // methods
     /// Resets the matrix to a deallocated state
     void reset();
 
@@ -289,16 +292,12 @@ private: // methods
     /// Deserialise from a Stream
     void decode(Stream& s);
 
-    /// Resize sparse matrix (invalidates all data arrays)
-    void resize(Size rows, Size cols);
+private:  // members
+    Layout spm_;
 
-private: // members
+    Shape shape_;
 
-    Layout    spm_;
-
-    Shape     shape_;
-
-    std::unique_ptr<SparseMatrix::Allocator> owner_;   ///< memory manager / allocator
+    std::unique_ptr<SparseMatrix::Allocator> owner_;  ///< memory manager / allocator
 
     friend Stream& operator<<(Stream&, const SparseMatrix&);
 };
@@ -307,7 +306,7 @@ Stream& operator<<(Stream&, const SparseMatrix&);
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace linalg
-} // namespace eckit
+}  // namespace linalg
+}  // namespace eckit
 
 #endif
