@@ -23,7 +23,8 @@ namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-ChannelBuffer::ChannelBuffer(std::size_t size) : std::streambuf(), target_(0), buffer_(size) {
+ChannelBuffer::ChannelBuffer(std::size_t size) :
+    std::streambuf(), target_(0), buffer_(size) {
     ASSERT(size);
     char* base = &buffer_.front();
     setp(base, base + buffer_.size());
