@@ -26,11 +26,10 @@ class LogTarget : public Counted {
 public:  // methods
     LogTarget();
 
-
     virtual void write(const char* start, const char* end) = 0;
     virtual void flush()                                   = 0;
 
-    virtual ~LogTarget();
+    virtual ~LogTarget() override;
 
 protected:
     friend std::ostream& operator<<(std::ostream& os, const LogTarget& c) {
