@@ -23,19 +23,16 @@ namespace eckit {
 //----------------------------------------------------------------------------------------------------------------------
 
 class StatusTarget : public LineBasedTarget {
-public: // methods
-
+public:  // methods
     StatusTarget();
 
 private:
-
-    virtual void line(const char* line);
-    virtual void print(std::ostream& s) const;
-
+    virtual void line(const char* line) override;
+    virtual void print(std::ostream& s) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 #endif
