@@ -70,7 +70,7 @@ inline Scalar det(Scalar m[16]);
 }  // namespace detail
 
 template <typename Scalar, typename Index = std::ptrdiff_t>
-class Matrix {
+class Matrix : private eckit::NonCopyable {
 
 protected:
     Scalar* data_;
@@ -116,6 +116,12 @@ public:
         memcpy(data_, other.data(), sizeof(Scalar) * nr_ * nc_);
     }
 
+    ~Matrix() {
+        if (!is_proxy_) {
+            delete[] data_;
+        }
+    }
+
     Matrix& noalias() { return *this; }
 
     void resize(Index nr, Index nc) {
@@ -385,7 +391,6 @@ public:
         Matrix dot(const Matrix& m) const {
         // Very naive implementation. We should use BLAS later
         Matrix result(rows(), m.cols());
-        result *= 0.;
         for (Index i = 0; i < rows(); ++i) {
             for (Index j = 0; j < m.cols(); ++j) {
                 result(i, j) = 0.;
