@@ -116,6 +116,11 @@ public:  // methods
     /// @brief Probe for incoming messages (blocking)
     virtual Status probe(int source, int tag) const = 0;
 
+    /// @brief Probe for incoming messages (non-blocking)
+    /// Use status.error() to check if there is an incoming message
+    /// status.error() == 0 if there is an incoming message
+    virtual Status iProbe(int source, int tag) const = 0;
+
     virtual int undefined() const = 0;
 
     virtual int anySource() const = 0;
