@@ -27,7 +27,6 @@ class Endpoint;
 
 class TCPClient : public TCPSocket, private eckit::NonCopyable {
 public:
-
     TCPClient(const SocketOptions& options = SocketOptions::none());
     TCPClient(int port, const SocketOptions& options = SocketOptions::none());
 
@@ -37,7 +36,7 @@ public:
     virtual TCPSocket& connect(const net::Endpoint& endpoint, int retries = 5, int timeout = 0);
 
 protected:  // methods
-    virtual void print(std::ostream& s) const;
+    virtual void print(std::ostream& s) const override;
 
     void buildSockAddress();
 
@@ -46,8 +45,8 @@ private:  // members
     SocketOptions options_;
 
 private:  // methods
-    virtual void bind();
-    virtual std::string bindingAddress() const { return options_.bindAddress();  }
+    virtual void bind() override;
+    virtual std::string bindingAddress() const override { return options_.bindAddress(); }
 };
 
 }  // namespace net
