@@ -42,12 +42,12 @@ namespace eckit {
 namespace net {
 
 
-
 static in_addr none = {INADDR_NONE};
 
 static Once<Mutex> local_mutex;
 
-TCPSocket::UnknownHost::UnknownHost(const std::string& host) : Exception(std::string("Unknown host ") + host) {}
+TCPSocket::UnknownHost::UnknownHost(const std::string& host) :
+    Exception(std::string("Unknown host ") + host) {}
 
 
 TCPSocket::TCPSocket() :
@@ -56,7 +56,6 @@ TCPSocket::TCPSocket() :
     remotePort_(-1),
     remoteAddr_(none),
     localAddr_(none),
-    bufSize_(0),
     debug_(false),
     newline_(true),
     mode_(0) {}
@@ -70,7 +69,6 @@ TCPSocket::TCPSocket(net::TCPSocket& other) :
     remoteAddr_(other.remoteAddr_),
     localHost_(other.localHost_),
     localAddr_(other.localAddr_),
-    bufSize_(0),
     debug_(false),
     newline_(true),
     mode_(0) {
@@ -128,7 +126,8 @@ long TCPSocket::write(const void* buf, long length) {
 
         if (mode_ != 'w') {
             newline_ = true;
-            std::cout << std::endl << std::endl;
+            std::cout << std::endl
+                      << std::endl;
             mode_ = 'w';
         }
 
@@ -143,7 +142,8 @@ long TCPSocket::write(const void* buf, long length) {
                 std::cout << "\\r";
             }
             else if (p[i] == '\n') {
-                std::cout << "\\n" << std::endl;
+                std::cout << "\\n"
+                          << std::endl;
                 newline_ = true;
             }
             else {
@@ -269,7 +269,8 @@ long TCPSocket::read(void* buf, long length) {
 
             if (mode_ != 'r') {
                 newline_ = true;
-                std::cout << std::endl << std::endl;
+                std::cout << std::endl
+                          << std::endl;
                 mode_ = 'r';
             }
 
@@ -283,7 +284,8 @@ long TCPSocket::read(void* buf, long length) {
                     std::cout << "\\r";
                 }
                 else if (p[i] == '\n') {
-                    std::cout << "\\n" << std::endl;
+                    std::cout << "\\n"
+                              << std::endl;
                     newline_ = true;
                 }
                 else {
@@ -480,6 +482,36 @@ TCPSocket& TCPClient::connect(const std::string& remote, int port, int retries,
     return *this;
 }
 
+void set_socket_buffer_size(int& socket, const char* ssock, const int& stype, const int size ) {
+    Log::debug() << "Setting " << ssock << " buffer size " << size << std::endl;
+
+    int flg           = 0;
+    socklen_t flgsize = sizeof(flg);
+
+    if (getsockopt(socket, SOL_SOCKET, stype, &flg, &flgsize) < 0)
+            Log::warning() << "getsockopt " << ssock << " " << Log::syserr << std::endl;
+
+   if (flg != size) {
+        if (setsockopt(socket, SOL_SOCKET, stype, &size, sizeof(size)) < 0)
+            Log::warning() << "setsockopt " << ssock << " " << Log::syserr << std::endl;
+
+        if (getsockopt(socket, SOL_SOCKET, stype, &flg, &flgsize) < 0)
+            Log::warning() << "getsockopt " << ssock << " " << Log::syserr << std::endl;
+
+        bool warn = (flg != size);
+#if defined(__linux__)
+        // For Linux we ignore if the effective size is 2x what is set
+        // see Linux 'man 7 socket'
+        // when set using setsockopt() the Linux kernel doubles the socket buffer size 
+        // to allow space for bookkeeping overhead and  this  doubled  value  is
+        // returned  by  getsockopt(). The minimum (doubled) value for this option is 2048.
+        warn &= !(flg == 2 * size);  
+#endif
+        if(warn)
+            Log::warning() << "Attempt to set " << stype << " buffer size to " << size << " but kernel set size to " << flg << std::endl;
+    }
+}
+
 
 int TCPSocket::createSocket(int port, const SocketOptions& opts) {
 
@@ -529,9 +561,6 @@ int TCPSocket::createSocket(int port, const SocketOptions& opts) {
         int tos = IPTOS_LOWDELAY;
         if (::setsockopt(s, IPPROTO_IP, IP_TOS, &tos, sizeof(tos)) < 0)
             Log::warning() << "setsockopt IP_TOS" << Log::syserr << std::endl;
-
-        /* #endif */
-        /* #endif */
     }
 
     if (opts.tcpNoDelay()) {
@@ -540,30 +569,15 @@ int TCPSocket::createSocket(int port, const SocketOptions& opts) {
             Log::warning() << "setsockopt TCP_NODELAY" << Log::syserr << std::endl;
     }
 
-    if (bufSize_) {
-
-        Log::info() << "SOCKET SIZE " << bufSize_ << std::endl;
-
-        int flg           = 0;
-        socklen_t flgsize = sizeof(flg);
-
-        if (getsockopt(s, SOL_SOCKET, SO_SNDBUF, &flg, &flgsize) < 0)
-            Log::warning() << "getsockopt SO_SNDBUF " << Log::syserr << std::endl;
-
-        if (flg != bufSize_) {
-            if (setsockopt(s, SOL_SOCKET, SO_SNDBUF, &bufSize_, sizeof(bufSize_)) < 0)
-                Log::warning() << "setsockopt SO_SNDBUF " << Log::syserr << std::endl;
-        }
-
-        if (getsockopt(s, SOL_SOCKET, SO_RCVBUF, &flg, &flgsize) < 0)
-            Log::warning() << "getsockopt SO_RCVBUF " << Log::syserr << std::endl;
-
-        if (flg != bufSize_) {
-            if (setsockopt(s, SOL_SOCKET, SO_RCVBUF, &bufSize_, sizeof(bufSize_)) < 0)
-                Log::warning() << "setsockopt SO_RCVBUF " << Log::syserr << std::endl;
-        }
+    receiveBufferSize_ = receiveBufferSize_ ? receiveBufferSize_ : opts.receiveBufferSize();
+    if (receiveBufferSize_) {
+        set_socket_buffer_size(s, "SO_RCVBUF", SO_RCVBUF, receiveBufferSize_);
     }
 
+    sendBufferSize_ = sendBufferSize_ ? sendBufferSize_ : opts.sendBufferSize();
+    if (sendBufferSize_) {
+        set_socket_buffer_size(s, "SO_SNDBUF", SO_SNDBUF, sendBufferSize_);
+    }
 
     sockaddr_in sin;
     ::memset(&sin, 0, sizeof(struct sockaddr_in));
@@ -783,11 +797,9 @@ void TCPSocket::debug(bool on) {
 }
 
 void TCPSocket::print(std::ostream& s) const {
-    s << "TCPSocket[fd=" << socket_
-    << ",remote[" << remoteHost() << ":" << remotePort()
-    << " (" << remoteAddr_ << ")]"
-    << ",local[" << localHost() << ":" << localPort()
-    << " (" << localAddr_ << ")]"
+    s << "TCPSocket[fd=" << socket_ << ",remote[" << remoteHost() << ":" << remotePort() << " (" << remoteAddr_ << ")]"
+      << ",local[" << localHost() << ":" << localPort() << " (" << localAddr_
+      << ")]"
       // << ",localPort=" << localPort_
       // << ",remotePort=" << remotePort_
       // << ",remoteHost=" << remoteHost_
@@ -803,6 +815,5 @@ std::ostream& operator<<(std::ostream& s, in_addr a) {
 }
 
 
-
 }  // namespace net
 }  // namespace eckit
