@@ -15,11 +15,10 @@ namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-HtmlResource::HtmlResource(const std::string& s) : HttpResource(s) {
-}
+HtmlResource::HtmlResource(const std::string& s) :
+    HttpResource(s) {}
 
-HtmlResource::~HtmlResource() {
-}
+HtmlResource::~HtmlResource() {}
 
 //----------------------------------------------------------------------------------------------------------------------
 
