@@ -35,9 +35,11 @@ template <typename T>
 class TestItem : public Streamable {
 
 public:
-    TestItem(const T& s) : payload_(s) {}
+    TestItem(const T& s) :
+        payload_(s) {}
 
-    TestItem(Stream& s) : Streamable(s), payload_() { s >> payload_; }
+    TestItem(Stream& s) :
+        Streamable(s), payload_() { s >> payload_; }
 
     // From Streamble
     virtual void encode(eckit::Stream& s) const {
